import { EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { CdkDragDrop } from '@angular/cdk/drag-drop';
import { FormGroup } from '@angular/forms';
import { AttributeItemSelector } from '../../shared/models/attributeItemSelector.model';
import * as i0 from "@angular/core";
export declare class AttributeSelectorComponent implements OnInit, OnChanges, OnDestroy {
    /**
     * The list of available attributes to be selected and deselected.
     */
    allAttributes: AttributeItemSelector[];
    /**
     * The list of selected attributes.
     */
    selectedAttributes: AttributeItemSelector[];
    /**
     * The maximum number of selected attributes.
     * Default value is 30.
     */
    maxSelectedAttributes: number;
    /**
     * The title of the attribute selector, displayed above the lists.
     */
    title: string;
    /**
     * The icon in the title of the attribute selector, displayed above the lists.
     * Has to be one of the available icons from the talenra icon library.
     */
    titleIcon: string;
    /**
     * The reset attribute selection.
     * If true, the attribute selection will be reset.
     * Will be set to false after the reset.
     */
    resetAttributeSelection: boolean;
    /**
     * The reset attribute selection emitter.
     * If true, the attribute selection will be reset.
     * Will be set to false after the reset.
     */
    resetAttributeSelectionChange: EventEmitter<boolean>;
    /**
     * The event emitter for the selected attributes.
     */
    selectedAttributesChange: EventEmitter<AttributeItemSelector[]>;
    /**
     * The event emitter for which specific custom space is clicked correlating with the attribute.
     */
    selectedAttributeIconClickEmitter: EventEmitter<AttributeItemSelector>;
    /**
     * The event emitter for the click of the close button.
     */
    closeClick: import("@angular/core").OutputEmitterRef<void>;
    /**
     * List of searched attributes, not selected.
     */
    searchedAttributesList: AttributeItemSelector[];
    /**
     * Form group for the search field
     */
    searchField: FormGroup;
    /**
     * Value if placeholder in selected sort list is shown.
     * If nothing selected yet, then placeholder is shown.
     */
    placeholderSelectionAttributesListShown: boolean;
    /**
     * Subscriptions for the filter toolbar component.
     * @internal
     */
    private subscriptions;
    /**
     * Standard initializer for the component.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Detects changes in the attribute selector component.
     * @param changes The changes in the attribute selector component.
     * @internal
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Unsubscribe from all subscriptions.
     * @internal
     */
    ngOnDestroy(): void;
    /**
     * To change the array place of dragged item.
     * Changes the order for the (selected) filters in the list of all filters (selected and not selected).
     * Updates the shown order in the dropdown list.
     * @param event The dragged item.
     * @internal
     */
    drop(event: CdkDragDrop<AttributeItemSelector[]>): void;
    /**
     * Remove the chosen filter from the used attributes.
     * @param attribute The chosen attribute.
     * @param index The index of the chosen attribute.
     */
    removeAttribute(attribute: AttributeItemSelector, index: number): void;
    /**
     * Add the chosen attribute to the used attributes.
     * Moves chosen attribute to the top of the list.
     * @param index The index of the chosen attribute.
     */
    addAttribute(index: number): void;
    /**
     * Function to delete all attributes from the selected attributes.
     */
    resetAttributes(): void;
    /**
     * Sets that the placeholder in the start sort list shown.
     */
    dropListEntered(): void;
    /**
     * Sets that the placeholder in the start sort list is not shown.
     */
    dropListExited(): void;
    /**
     * Attributes icon click emitter to enable the tracking which attribute icon is clicked.
     */
    selectedAttributesIconClicked(attribute: AttributeItemSelector): void;
    /**
     * Method to emit the close button and close the inbox detail view
     */
    onCloseClick(): void;
    /**
     * Function to reset the search field.
     * @private
     */
    private resetSearchText;
    /**
     * Function to initialize the component.
     * @private
     */
    private initializeComponent;
    static ɵfac: i0.ɵɵFactoryDeclaration<AttributeSelectorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AttributeSelectorComponent, "talenra-attribute-selector", never, { "allAttributes": { "alias": "allAttributes"; "required": false; }; "selectedAttributes": { "alias": "selectedAttributes"; "required": false; }; "maxSelectedAttributes": { "alias": "maxSelectedAttributes"; "required": false; }; "title": { "alias": "title"; "required": false; }; "titleIcon": { "alias": "titleIcon"; "required": false; }; "resetAttributeSelection": { "alias": "resetAttributeSelection"; "required": false; }; }, { "resetAttributeSelectionChange": "resetAttributeSelectionChange"; "selectedAttributesChange": "selectedAttributesChange"; "selectedAttributeIconClickEmitter": "selectedAttributeIconClickEmitter"; "closeClick": "closeClick"; }, never, never, false, never>;
}
