import { EventEmitter } from '@angular/core';
import { IconInput } from '../../shared/models/iconInput.model';
import { SelectedFilterValueModel } from '../../shared/models/selectedFilterValue.model';
import * as i0 from "@angular/core";
/**
 * Component to display the four icon filters and handle the click of them.
 *
 * ```html
 * <talenra-icon-filters
 *   (valuesSelected)="valuesSelected($event.filterType, $event.filterIdentifier, $event.value)"
 *   [activeFilters]="activeFilters"
 *   [iconFilters]="iconFilters"
 * ></talenra-icon-filters>
 * ```
 */
export declare class IconFiltersComponent {
    /**
     * The list of filters to be displayed.
     */
    activeIcons: Map<string, [string, string | boolean | string[] | number[] | Date[]]>;
    /**
     * List of given IconFilters.
     */
    availableIcons: IconInput[];
    /**
     * The output event when a filter is selected.
     */
    valuesSelected: EventEmitter<SelectedFilterValueModel>;
    /**
     * The type of filter to be used.
     */
    private filterType;
    /**
     * Method to save and emit changes.
     * @param iconInput The icon that changed and is to be emitted.
     * @param event The value if the filter is selected or not.
     */
    onValuesSelected(iconInput: IconInput, event: boolean): void;
    /**
     * Method to get the combined filter object.
     * @param filterObject The filter object to be combined.
     */
    getCombinedFilterLabel(filterObject: IconInput): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IconFiltersComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IconFiltersComponent, "talenra-icon-filter", never, { "activeIcons": { "alias": "activeIcons"; "required": false; }; "availableIcons": { "alias": "availableIcons"; "required": false; }; }, { "valuesSelected": "valuesSelected"; }, never, never, false, never>;
}
