import { AfterContentInit, OnDestroy } from '@angular/core';
import { InboxDetailViewService } from '../inbox-detail-view.service';
import { DetailViewItemModel } from '../../../shared/models/detailViewItem.model';
import * as i0 from "@angular/core";
/**
 * The data item information tab bar and data item information components are merged into the data item information box
 * for better handling.
 *
 * ```html
 * <talenra-detail-view-information-box
 *   [dataItemInformationTabBarItems]="dataItemInformationTabBarItems"
 * ></talenra-detail-view-information-box>
 * ```
 */
export declare class DetailViewInformationBoxComponent implements OnDestroy, AfterContentInit {
    /**
     * List of all data item information tab bar items
     */
    detailViewInformationTabBarItems: import("@angular/core").InputSignal<DetailViewItemModel[]>;
    /**
     * The selected tab.
     */
    selectedTab: import("@angular/core").ModelSignal<string>;
    /**
     * The public service of the inbox detail view.
     */
    inboxDetailViewService: InboxDetailViewService;
    /**
     * Subscriptions of the data item information box.
     *  @internal
     */
    private subscriptions;
    /**
     * Subscribe to isExpanded$ to un-select data item information tab bar item if inbox layout is collapsed.
     * @internal
     */
    ngAfterContentInit(): void;
    /**
     * Unsubscribe from all subscriptions.
     * @internal
     */
    ngOnDestroy(): void;
    /**
     * Selects the specific tab and expands the layout with layout service.
     * @param key The key of the selected tab.
     */
    onTabChange(key: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DetailViewInformationBoxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DetailViewInformationBoxComponent, "talenra-detail-view-information-box", never, { "detailViewInformationTabBarItems": { "alias": "detailViewInformationTabBarItems"; "required": true; "isSignal": true; }; "selectedTab": { "alias": "selectedTab"; "required": false; "isSignal": true; }; }, { "selectedTab": "selectedTabChange"; }, never, ["[data-item-information-outlet]"], false, never>;
}
