import { BehaviorSubject } from 'rxjs';
import { AttributeItem } from '../../shared/models/attributeItem.model';
import { PresetGroup } from '../../shared/models/presetGroup.model';
import { InboxState } from '../state/inbox.state';
import * as i0 from "@angular/core";
/**
 * The service to check if the values of the filter and sort are changed in comparison to the default values of the preset.
 * @ignore
 */
export declare class ChangedPresetValuesService {
    /**
     * The state of the inbox.
     */
    inboxState: InboxState;
    /**
     * The subject to check if the attributes are changed in comparison to the active preset.
     */
    readonly attributesMainChangedSubject$: BehaviorSubject<{
        identifier: string;
        changed: boolean;
    }>;
    /**
     * The subject to check if the attributes details are changed in comparison to the active preset.
     */
    readonly attributesDetailChangedSubject$: BehaviorSubject<{
        identifier: string;
        changed: boolean;
    }>;
    /**
     * The subject to check if the number of main attributes chosen by the user is changed in comparison to the active preset.
     */
    readonly numberMainAttributesChosenByUserChangedSubject$: BehaviorSubject<{
        identifier: string;
        changed: boolean;
    }>;
    /**
     * The subject to check if the sort is changed in comparison to the active preset.
     */
    readonly sortChangedSubject$: BehaviorSubject<{
        identifier: string;
        changed: boolean;
    }>;
    /**
     * The subject to check if the filter is changed in comparison to the active preset.
     */
    readonly filterChangedSubject$: BehaviorSubject<{
        identifier: string;
        changed: boolean;
    }>;
    /**
     * Value if there are changes of the filter and sort from the default values of the preset.
     */
    readonly filterSortChangedSubject$: BehaviorSubject<boolean>;
    /**
     * Set the attributes changed subject.
     * @param key The key to set the attributes changed subject.
     */
    setAttributesMainChangedSubject(key: {
        identifier: string;
        changed: boolean;
    }): void;
    /**
     * Set the attributes details changed subject.
     * @param key The key to set the attributes details changed subject.
     */
    setAttributesDetailChangedSubject(key: {
        identifier: string;
        changed: boolean;
    }): void;
    /**
     * Set the number of main attributes chosen by the user changed subject.
     * @param key The key to set the number of main attributes chosen by the user changed subject.
     */
    setNumberMainAttributesChosenByUserChangedSubject(key: {
        identifier: string;
        changed: boolean;
    }): void;
    /**
     * Set the sort changed subject.
     * @param key The key to set the sort changed subject.
     */
    setSortChangedSubject(key: {
        identifier: string;
        changed: boolean;
    }): void;
    /**
     * Set the filter changed subject.
     * @param key The key to set the filter changed subject.
     */
    setFilterChangedSubject(key: {
        identifier: string;
        changed: boolean;
    }): void;
    /**
     * Set the filter and sort changed subject.
     * @param key The key to set the filter and sort changed subject.
     */
    setFilterSortChangedSubject$(key: boolean): void;
    /**
     * Checks if attributes are changed in comparison to the active preset.
     */
    setPresetGroupsAndCompareIfChangedAttributes(selectedMainAttributes: AttributeItem[], selectedDetailAttributes: AttributeItem[], numberMainAttributesChosenByUser: number, presetGroups: PresetGroup[]): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChangedPresetValuesService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ChangedPresetValuesService>;
}
