import { FilterAttribute } from './filterAttribute.interface';
import { SortAttributesInput } from '../models/sortAttributesInput.model';
import { IconFiltersInput } from '../models/iconFiltersInput.model';
/**
 * FilterSortSearchModel is used to define what kind of filters, sort and searched text are used in the inbox.
 *
 * @example
 * import { FilterSortSearchModel } from '@talenra/ngx-inbox';
 *
 * filterSortSearch: FilterSortSearchModel = {
 *   searchText: 'searched text',
 *   sortAttributes: [{identifier: 'caseId', sort: 'asc'}],
 *   filterAttributes: [{ identifier: 'animal.mammal', value: [{ key: 'landAnimalMonkey', label: 'Monkey' }, { key: 'waterAnimalWhale', label: 'Whale' }] },  { identifier: 'animal.mammal', value: { start: 'AR', end: 'JAB' } }],
 *   iconAttributes: [{ icon: "error", identifier: "icon_error_insuree.partnerFlags" }],
 *   };
 */
export interface FilterSortSearch {
    /**
     * Searched text in the search bar.
     **/
    searchText: string;
    /**
     * SortAttributes is used to define which attributes are used to sort the items in the inbox.
     */
    sortAttributes: SortAttributesInput[];
    /**
     * FilterAttributes is used to define which attributes are used to filter the items in the inbox.
     */
    filterAttributes: FilterAttribute[];
    /**
     * IconAttributes is used to define which icon filters are active in the inbox.
     */
    iconAttributes: IconFiltersInput[];
}
