import { NoteBoxItem } from './noteBoxItem';
import { AttributeItem } from './attributeItem.model';
import { IconInput } from './iconInput.model';
/**
 * DataItemClass necessary to check:
 * - if a string value is contained in all the string attributes of a data item
 * - if a data item is a duplicate
 * - to create the notes from a data item
 * - to get a property from a data item
 * - to format a date to MM/DD/YYYY
 * - to check if a date is invalid
 *
 */
export declare class DataItemsClass {
    /**
     * This function is to check if a string value is contained in "stringish" attributes (string, number, Date) of a
     * data item.
     *
     * @param specificDataItem The data item to check.
     * @param query The value to check.
     * @param mainAttributes The main attributes of the data item.
     * @param detailAttributes The detail attributes of the data item.
     */
    contains(specificDataItem: any, query: string | null, mainAttributes: AttributeItem[], detailAttributes: AttributeItem[]): boolean;
    /**
     * This method is used to create the notes from a data item.
     * @param dataItem The data item to create the notes from.
     * @param iconAttributes The icon attributes to create the notes from.
     */
    createNotesFromDataItem(dataItem: any, iconAttributes: IconInput[]): NoteBoxItem[];
    /**
     * This method is used to get a property from a data item.
     * @param specificDataItem The data item to get the property from.
     * @param label The label of the property to get.
     */
    getElemFromDataItemDisplayed(specificDataItem: any, label: string): any;
    /**
     * Auxiliary method to get the value of a property from a data item.
     * Returns null, Number, Date or string values.
     * @param specificDataItem The data item to get the property from.
     * @param label The label of the property to get.
     */
    getElemFromDataItemValue(specificDataItem: any, label: string): any;
    /**
     * This method is used to set a property from a data item.
     * @param specificDataItem The data item to set the property from.
     * @param label The label of the property to set.
     * @param value The value to set.
     */
    setElemFromDataItemValue(specificDataItem: any, label: string, value: any): void;
    /**
     * This method is used to get a property from a data item.
     * @param object The object to get the property from.
     * @param keys The keys of the property to get.
     */
    getProp(object: any, keys: string[]): any;
    /**
     * This method is used to set a property from a data item.
     * @param object
     * @param keys
     * @param value
     */
    setProp(object: any, keys: string[], value: any): void;
    /**
     * Format a date to MM/DD/YYYY from DD.MM.YYYY.
     * @param date The date to format.
     */
    formatDate(date: any): any;
    /**
     * Check if a date is invalid.
     * @param dateString The date to check.
     */
    isDateInvalid(dateString: string): boolean;
}
