import { IconFiltersInput } from './iconFiltersInput.model';
import { SortAttributesInput } from './sortAttributesInput.model';
import { FilterAttributesInput } from './filterAttributesInput.model';
/**
 * FilterSortSearchModel is used to define what kind of filters, sort and searched text are used in the inbox.
 *
 * @example
 * import { FilterSortSearchModel } from '@talenra/ngx-inbox';
 *
 * filterSortSearch: FilterSortSearchModel = {
 *   searchText: 'searched text',
 *   sortAttributes: [{identifier: 'caseId', sort: 'asc'}],
 *   filterAttributes: [{ identifier: 'insureelastNameOrgName', value: ['8001', '8041', '8011'] }],
 *   iconAttributes: [{ icon: "error", identifier: "icon_error_insuree.partnerFlags" }],
 *   };
 */
export interface FilterSortSearchModel {
    /**
     * Searched text in the search bar.
     **/
    searchText: string;
    /**
     * SortAttributes is used to define which attributes are used to sort the items in the inbox.
     */
    sortAttributes: SortAttributesInput[];
    /**
     * FilterAttributes is used to define which attributes are used to filter the items in the inbox.
     */
    filterAttributes: FilterAttributesInput[];
    /**
     * IconAttributes is used to define which icon filters are active in the inbox.
     */
    iconAttributes: IconFiltersInput[];
}
